@@ -18,18 +18,22 @@ module Hamlit
 
     desc 'compile HAML', 'Show compile result'
     option :actionview, type: :boolean, default: false, aliases: %w[-a]
+    option :color, type: :boolean, default: false, aliases: %w[-c]
     def compile(file)
-      print_code generate_code(file)
+      code = generate_code(file)
+      puts_code(code, color: options[:color])
     end
 
     desc 'temple HAML', 'Show temple intermediate expression'
+    option :color, type: :boolean, default: false, aliases: %w[-c]
     def temple(file)
-      pp generate_temple(file)
+      pp_object(generate_temple(file), color: options[:color])
     end
 
     desc 'parse HAML', 'Show parse result'
+    option :color, type: :boolean, default: false, aliases: %w[-c]
     def parse(file)
-      pp generate_ast(file)
+      pp_object(generate_ast(file), color: options[:color])
     end
 
     desc 'version', 'Show the used hamlit version'
@@ -51,8 +55,16 @@ module Hamlit
       end
     end
 
+    def read_file(file)
+      if file == '-'
+        STDIN.read
+      else
+        File.read(file)
+      end
+    end
+
     def generate_code(file)
-      template = File.read(file)
+      template = read_file(file)
       if options[:actionview]
         require 'action_view'
         require 'action_view/base'
@@ -60,7 +72,7 @@ module Hamlit
         handler = Hamlit::RailsTemplate.new
         template = ActionView::Template.new(template, 'inline template', handler, { locals: [] })
         code = handler.call(template)
-        source = <<-end_src
+        <<-end_src
           def _inline_template___2144273726781623612_70327218547300(local_assigns, output_buffer)
             _old_virtual_path, @virtual_path = @virtual_path, nil;_old_output_buffer = @output_buffer;;#{code}
           ensure
@@ -73,7 +85,7 @@ module Hamlit
     end
 
     def generate_ast(file)
-      template = File.read(file)
+      template = read_file(file)
       Hamlit::Parser.new(engine_options).call(template)
     end
 
@@ -95,20 +107,24 @@ module Hamlit
       render(args.first.to_s)
     end
 
-    def print_code(code)
-      require 'pry'
-      puts Pry.Code(code).highlighted
-    rescue LoadError
-      puts code
+    def puts_code(code, color: false)
+      if color
+        require 'pry'
+        puts Pry.Code(code).highlighted
+      else
+        puts code
+      end
     end
 
     # Enable colored pretty printing only for development environment.
-    def pp(arg)
-      require 'pry'
-      Pry::ColorPrinter.pp(arg)
-    rescue LoadError
-      require 'pp'
-      super(arg)
+    def pp_object(arg, color: false)
+      if color
+        require 'pry'
+        Pry::ColorPrinter.pp(arg)
+      else
+        require 'pp'
+        pp(arg)
+      end
     end
   end
 end
