@@ -2,10 +2,10 @@
 require 'temple'
 require 'hamlit/parser'
 require 'hamlit/compiler'
+require 'hamlit/html'
 require 'hamlit/escapable'
 require 'hamlit/force_escapable'
-require 'hamlit/html'
-require 'hamlit/string_splitter'
+require 'hamlit/dynamic_merger'
 
 module Hamlit
   class Engine < Temple::Engine
@@ -25,13 +25,14 @@ module Hamlit
     use Parser
     use Compiler
     use HTML
-    use StringSplitter
+    filter :StringSplitter
     filter :StaticAnalyzer
     use Escapable
     use ForceEscapable
     filter :ControlFlow
     filter :MultiFlattener
     filter :StaticMerger
+    use DynamicMerger
     use :Generator, -> { options[:generator] }
   end
 end
