@@ -3,7 +3,7 @@ module Hamlit
   class Filters
     class Coffee < TiltBase
       def compile(node)
-        require 'tilt/coffee' if explicit_require?
+        require 'tilt/coffee' if explicit_require?('coffee')
         temple = [:multi]
         temple << [:static, "<script>\n"]
         temple << compile_with_tilt(node, 'coffee', indent_width: 2)
