@@ -2,7 +2,7 @@ module Hamlit
   class Filters
     class Markdown < TiltBase
       def compile(node)
-        require 'tilt/redcarpet' if explicit_require?
+        require 'tilt/redcarpet' if explicit_require?('markdown')
         compile_with_tilt(node, 'markdown')
       end
     end
