@@ -3,7 +3,7 @@ module Hamlit
   class Filters
     class Scss < TiltBase
       def compile(node)
-        require 'tilt/sass' if explicit_require?
+        require 'tilt/sass' if explicit_require?('scss')
         temple = [:multi]
         temple << [:static, "<style>\n"]
         temple << compile_with_tilt(node, 'scss', indent_width: 2)
