@@ -1292,14 +1292,14 @@ HAML
                   render("/![if !IE] A comment"))
   end
 
-  def test_downlevel_revealed_conditional_comments_block; skip
-    assert_equal("<!--[if !IE]><!-->\n  A comment\n<!--<![endif]-->\n",
+  def test_downlevel_revealed_conditional_comments_block
+    assert_equal("<!--[if !IE]><!-->\nA comment\n<!--<![endif]-->\n",
                   render("/![if !IE]\n  A comment"))
   end
 
   def test_local_assigns_dont_modify_class
     assert_haml_ugly("= foo", :locals => {:foo => 'bar'})
-    assert_equal(nil, defined?(foo))
+    assert_nil(defined?(foo))
   end
 
   def test_object_ref_with_nil_id; skip # object reference
@@ -2105,4 +2105,4 @@ HTML
     assert_equal expected.encoding, actual.encoding
     assert_equal expected, actual
   end
-end
+end if RUBY_ENGINE != 'truffleruby' # truffleruby cannot run Haml
