@@ -21,7 +21,7 @@ class UglyTest < MiniTest::Test
   class Headers < MiniTest::Test
     def test_an_XHTML_XML_prolog
       haml    = %q{!!! XML}
-      html    = %q{<?xml version='1.0' encoding='utf-8' ?>}
+      _html   = %q{<?xml version='1.0' encoding='utf-8' ?>}
       locals  = {}
       options = {:format=>:xhtml}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -31,7 +31,7 @@ class UglyTest < MiniTest::Test
 
     def test_an_XHTML_default_transitional_doctype
       haml    = %q{!!!}
-      html    = %q{<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">}
+      _html   = %q{<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">}
       locals  = {}
       options = {:format=>:xhtml}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -41,7 +41,7 @@ class UglyTest < MiniTest::Test
 
     def test_an_XHTML_1_1_doctype
       haml    = %q{!!! 1.1}
-      html    = %q{<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">}
+      _html   = %q{<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">}
       locals  = {}
       options = {:format=>:xhtml}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -51,7 +51,7 @@ class UglyTest < MiniTest::Test
 
     def test_an_XHTML_1_2_mobile_doctype
       haml    = %q{!!! mobile}
-      html    = %q{<!DOCTYPE html PUBLIC "-//WAPFORUM//DTD XHTML Mobile 1.2//EN" "http://www.openmobilealliance.org/tech/DTD/xhtml-mobile12.dtd">}
+      _html   = %q{<!DOCTYPE html PUBLIC "-//WAPFORUM//DTD XHTML Mobile 1.2//EN" "http://www.openmobilealliance.org/tech/DTD/xhtml-mobile12.dtd">}
       locals  = {}
       options = {:format=>:xhtml}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -61,7 +61,7 @@ class UglyTest < MiniTest::Test
 
     def test_an_XHTML_1_1_basic_doctype
       haml    = %q{!!! basic}
-      html    = %q{<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML Basic 1.1//EN" "http://www.w3.org/TR/xhtml-basic/xhtml-basic11.dtd">}
+      _html   = %q{<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML Basic 1.1//EN" "http://www.w3.org/TR/xhtml-basic/xhtml-basic11.dtd">}
       locals  = {}
       options = {:format=>:xhtml}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -71,7 +71,7 @@ class UglyTest < MiniTest::Test
 
     def test_an_XHTML_1_0_frameset_doctype
       haml    = %q{!!! frameset}
-      html    = %q{<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Frameset//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-frameset.dtd">}
+      _html   = %q{<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Frameset//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-frameset.dtd">}
       locals  = {}
       options = {:format=>:xhtml}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -81,7 +81,7 @@ class UglyTest < MiniTest::Test
 
     def test_an_HTML_5_doctype_with_XHTML_syntax
       haml    = %q{!!! 5}
-      html    = %q{<!DOCTYPE html>}
+      _html   = %q{<!DOCTYPE html>}
       locals  = {}
       options = {:format=>:xhtml}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -91,7 +91,7 @@ class UglyTest < MiniTest::Test
 
     def test_an_HTML_5_XML_prolog_silent_
       haml    = %q{!!! XML}
-      html    = %q{}
+      _html   = %q{}
       locals  = {}
       options = {:format=>:html5}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -101,7 +101,7 @@ class UglyTest < MiniTest::Test
 
     def test_an_HTML_5_doctype
       haml    = %q{!!!}
-      html    = %q{<!DOCTYPE html>}
+      _html   = %q{<!DOCTYPE html>}
       locals  = {}
       options = {:format=>:html5}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -111,7 +111,7 @@ class UglyTest < MiniTest::Test
 
     def test_an_HTML_4_XML_prolog_silent_
       haml    = %q{!!! XML}
-      html    = %q{}
+      _html   = %q{}
       locals  = {}
       options = {:format=>:html4}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -121,7 +121,7 @@ class UglyTest < MiniTest::Test
 
     def test_an_HTML_4_default_transitional_doctype
       haml    = %q{!!!}
-      html    = %q{<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">}
+      _html   = %q{<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">}
       locals  = {}
       options = {:format=>:html4}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -131,7 +131,7 @@ class UglyTest < MiniTest::Test
 
     def test_an_HTML_4_frameset_doctype
       haml    = %q{!!! frameset}
-      html    = %q{<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Frameset//EN" "http://www.w3.org/TR/html4/frameset.dtd">}
+      _html   = %q{<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Frameset//EN" "http://www.w3.org/TR/html4/frameset.dtd">}
       locals  = {}
       options = {:format=>:html4}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -141,7 +141,7 @@ class UglyTest < MiniTest::Test
 
     def test_an_HTML_4_strict_doctype
       haml    = %q{!!! strict}
-      html    = %q{<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">}
+      _html   = %q{<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">}
       locals  = {}
       options = {:format=>:html4}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -153,7 +153,7 @@ class UglyTest < MiniTest::Test
   class Basichamltagsandcss < MiniTest::Test
     def test_a_simple_Haml_tag
       haml    = %q{%p}
-      html    = %q{<p></p>}
+      _html   = %q{<p></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -163,7 +163,7 @@ class UglyTest < MiniTest::Test
 
     def test_a_self_closing_tag_XHTML_
       haml    = %q{%meta}
-      html    = %q{<meta />}
+      _html   = %q{<meta />}
       locals  = {}
       options = {:format=>:xhtml}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -173,7 +173,7 @@ class UglyTest < MiniTest::Test
 
     def test_a_self_closing_tag_HTML4_
       haml    = %q{%meta}
-      html    = %q{<meta>}
+      _html   = %q{<meta>}
       locals  = {}
       options = {:format=>:html4}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -183,7 +183,7 @@ class UglyTest < MiniTest::Test
 
     def test_a_self_closing_tag_HTML5_
       haml    = %q{%meta}
-      html    = %q{<meta>}
+      _html   = %q{<meta>}
       locals  = {}
       options = {:format=>:html5}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -193,7 +193,7 @@ class UglyTest < MiniTest::Test
 
     def test_a_self_closing_tag_modifier_XHTML_
       haml    = %q{%zzz/}
-      html    = %q{<zzz />}
+      _html   = %q{<zzz />}
       locals  = {}
       options = {:format=>:xhtml}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -203,7 +203,7 @@ class UglyTest < MiniTest::Test
 
     def test_a_self_closing_tag_modifier_HTML5_
       haml    = %q{%zzz/}
-      html    = %q{<zzz>}
+      _html   = %q{<zzz>}
       locals  = {}
       options = {:format=>:html5}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -213,7 +213,7 @@ class UglyTest < MiniTest::Test
 
     def test_a_tag_with_a_CSS_class
       haml    = %q{%p.class1}
-      html    = %q{<p class='class1'></p>}
+      _html   = %q{<p class='class1'></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -223,7 +223,7 @@ class UglyTest < MiniTest::Test
 
     def test_a_tag_with_multiple_CSS_classes
       haml    = %q{%p.class1.class2}
-      html    = %q{<p class='class1 class2'></p>}
+      _html   = %q{<p class='class1 class2'></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -233,7 +233,7 @@ class UglyTest < MiniTest::Test
 
     def test_a_tag_with_a_CSS_id
       haml    = %q{%p#id1}
-      html    = %q{<p id='id1'></p>}
+      _html   = %q{<p id='id1'></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -243,7 +243,7 @@ class UglyTest < MiniTest::Test
 
     def test_a_tag_with_multiple_CSS_id_s
       haml    = %q{%p#id1#id2}
-      html    = %q{<p id='id2'></p>}
+      _html   = %q{<p id='id2'></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -253,7 +253,7 @@ class UglyTest < MiniTest::Test
 
     def test_a_tag_with_a_class_followed_by_an_id
       haml    = %q{%p.class1#id1}
-      html    = %q{<p class='class1' id='id1'></p>}
+      _html   = %q{<p class='class1' id='id1'></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -263,7 +263,7 @@ class UglyTest < MiniTest::Test
 
     def test_a_tag_with_an_id_followed_by_a_class
       haml    = %q{%p#id1.class1}
-      html    = %q{<p class='class1' id='id1'></p>}
+      _html   = %q{<p class='class1' id='id1'></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -273,7 +273,7 @@ class UglyTest < MiniTest::Test
 
     def test_an_implicit_div_with_a_CSS_id
       haml    = %q{#id1}
-      html    = %q{<div id='id1'></div>}
+      _html   = %q{<div id='id1'></div>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -283,7 +283,7 @@ class UglyTest < MiniTest::Test
 
     def test_an_implicit_div_with_a_CSS_class
       haml    = %q{.class1}
-      html    = %q{<div class='class1'></div>}
+      _html   = %q{<div class='class1'></div>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -295,7 +295,7 @@ class UglyTest < MiniTest::Test
       haml    = %q{%div
   %div
     %p}
-      html    = %q{<div>
+      _html   = %q{<div>
   <div>
     <p></p>
   </div>
@@ -311,7 +311,7 @@ class UglyTest < MiniTest::Test
   class Tagswithunusualhtmlcharacters < MiniTest::Test
     def test_a_tag_with_colons
       haml    = %q{%ns:tag}
-      html    = %q{<ns:tag></ns:tag>}
+      _html   = %q{<ns:tag></ns:tag>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -321,7 +321,7 @@ class UglyTest < MiniTest::Test
 
     def test_a_tag_with_underscores
       haml    = %q{%snake_case}
-      html    = %q{<snake_case></snake_case>}
+      _html   = %q{<snake_case></snake_case>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -331,7 +331,7 @@ class UglyTest < MiniTest::Test
 
     def test_a_tag_with_dashes
       haml    = %q{%dashed-tag}
-      html    = %q{<dashed-tag></dashed-tag>}
+      _html   = %q{<dashed-tag></dashed-tag>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -341,7 +341,7 @@ class UglyTest < MiniTest::Test
 
     def test_a_tag_with_camelCase
       haml    = %q{%camelCase}
-      html    = %q{<camelCase></camelCase>}
+      _html   = %q{<camelCase></camelCase>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -351,7 +351,7 @@ class UglyTest < MiniTest::Test
 
     def test_a_tag_with_PascalCase
       haml    = %q{%PascalCase}
-      html    = %q{<PascalCase></PascalCase>}
+      _html   = %q{<PascalCase></PascalCase>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -363,7 +363,7 @@ class UglyTest < MiniTest::Test
   class Tagswithunusualcssidentifiers < MiniTest::Test
     def test_an_all_numeric_class
       haml    = %q{.123}
-      html    = %q{<div class='123'></div>}
+      _html   = %q{<div class='123'></div>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -373,7 +373,7 @@ class UglyTest < MiniTest::Test
 
     def test_a_class_with_underscores
       haml    = %q{.__}
-      html    = %q{<div class='__'></div>}
+      _html   = %q{<div class='__'></div>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -383,7 +383,7 @@ class UglyTest < MiniTest::Test
 
     def test_a_class_with_dashes
       haml    = %q{.--}
-      html    = %q{<div class='--'></div>}
+      _html   = %q{<div class='--'></div>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -395,7 +395,7 @@ class UglyTest < MiniTest::Test
   class Tagswithinlinecontent < MiniTest::Test
     def test_Inline_content_simple_tag
       haml    = %q{%p hello}
-      html    = %q{<p>hello</p>}
+      _html   = %q{<p>hello</p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -405,7 +405,7 @@ class UglyTest < MiniTest::Test
 
     def test_Inline_content_tag_with_CSS
       haml    = %q{%p.class1 hello}
-      html    = %q{<p class='class1'>hello</p>}
+      _html   = %q{<p class='class1'>hello</p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -417,7 +417,7 @@ class UglyTest < MiniTest::Test
       haml    = %q{%div
   %div
     %p text}
-      html    = %q{<div>
+      _html   = %q{<div>
   <div>
     <p>text</p>
   </div>
@@ -434,7 +434,7 @@ class UglyTest < MiniTest::Test
     def test_Nested_content_simple_tag
       haml    = %q{%p
   hello}
-      html    = %q{<p>
+      _html   = %q{<p>
   hello
 </p>}
       locals  = {}
@@ -447,7 +447,7 @@ class UglyTest < MiniTest::Test
     def test_Nested_content_tag_with_CSS
       haml    = %q{%p.class1
   hello}
-      html    = %q{<p class='class1'>
+      _html   = %q{<p class='class1'>
   hello
 </p>}
       locals  = {}
@@ -462,7 +462,7 @@ class UglyTest < MiniTest::Test
   %div
     %p
       text}
-      html    = %q{<div>
+      _html   = %q{<div>
   <div>
     <p>
       text
@@ -480,7 +480,7 @@ class UglyTest < MiniTest::Test
   class Tagswithhtmlstyleattributes < MiniTest::Test
     def test_HTML_style_one_attribute
       haml    = %q{%p(a='b')}
-      html    = %q{<p a='b'></p>}
+      _html   = %q{<p a='b'></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -490,7 +490,7 @@ class UglyTest < MiniTest::Test
 
     def test_HTML_style_multiple_attributes
       haml    = %q{%p(a='b' c='d')}
-      html    = %q{<p a='b' c='d'></p>}
+      _html   = %q{<p a='b' c='d'></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -501,7 +501,7 @@ class UglyTest < MiniTest::Test
     def test_HTML_style_attributes_separated_with_newlines
       haml    = %q{%p(a='b'
   c='d')}
-      html    = %q{<p a='b' c='d'></p>}
+      _html   = %q{<p a='b' c='d'></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -511,7 +511,7 @@ class UglyTest < MiniTest::Test
 
     def test_HTML_style_interpolated_attribute
       haml    = %q{%p(a="#{var}")}
-      html    = %q{<p a='value'></p>}
+      _html   = %q{<p a='value'></p>}
       locals  = {:var=>"value"}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -521,7 +521,7 @@ class UglyTest < MiniTest::Test
 
     def test_HTML_style_class_as_an_attribute
       haml    = %q{%p(class='class1')}
-      html    = %q{<p class='class1'></p>}
+      _html   = %q{<p class='class1'></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -531,7 +531,7 @@ class UglyTest < MiniTest::Test
 
     def test_HTML_style_tag_with_a_CSS_class_and_class_as_an_attribute
       haml    = %q{%p.class2(class='class1')}
-      html    = %q{<p class='class1 class2'></p>}
+      _html   = %q{<p class='class1 class2'></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -541,7 +541,7 @@ class UglyTest < MiniTest::Test
 
     def test_HTML_style_tag_with_id_as_an_attribute
       haml    = %q{%p(id='1')}
-      html    = %q{<p id='1'></p>}
+      _html   = %q{<p id='1'></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -551,7 +551,7 @@ class UglyTest < MiniTest::Test
 
     def test_HTML_style_tag_with_a_CSS_id_and_id_as_an_attribute
       haml    = %q{%p#id(id='1')}
-      html    = %q{<p id='id_1'></p>}
+      _html   = %q{<p id='id_1'></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -561,7 +561,7 @@ class UglyTest < MiniTest::Test
 
     def test_HTML_style_tag_with_a_variable_attribute
       haml    = %q{%p(class=var)}
-      html    = %q{<p class='hello'></p>}
+      _html   = %q{<p class='hello'></p>}
       locals  = {:var=>"hello"}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -571,7 +571,7 @@ class UglyTest < MiniTest::Test
 
     def test_HTML_style_tag_with_a_CSS_class_and_class_as_a_variable_attribute
       haml    = %q{.hello(class=var)}
-      html    = %q{<div class='hello world'></div>}
+      _html   = %q{<div class='hello world'></div>}
       locals  = {:var=>"world"}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -581,7 +581,7 @@ class UglyTest < MiniTest::Test
 
     def test_HTML_style_tag_multiple_CSS_classes_sorted_correctly_
       haml    = %q{.z(class=var)}
-      html    = %q{<div class='a z'></div>}
+      _html   = %q{<div class='a z'></div>}
       locals  = {:var=>"a"}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -592,7 +592,7 @@ class UglyTest < MiniTest::Test
     def test_HTML_style_tag_with_an_atomic_attribute
       skip '[INCOMPATIBILITY] Hamlit limits boolean attributes'
       haml    = %q{%a(flag)}
-      html    = %q{<a flag></a>}
+      _html   = %q{<a flag></a>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -604,7 +604,7 @@ class UglyTest < MiniTest::Test
   class Tagswithrubystyleattributes < MiniTest::Test
     def test_Ruby_style_one_attribute
       haml    = %q{%p{:a => 'b'}}
-      html    = %q{<p a='b'></p>}
+      _html   = %q{<p a='b'></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -614,7 +614,7 @@ class UglyTest < MiniTest::Test
 
     def test_Ruby_style_attributes_hash_with_whitespace
       haml    = %q{%p{  :a  =>  'b'  }}
-      html    = %q{<p a='b'></p>}
+      _html   = %q{<p a='b'></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -624,7 +624,7 @@ class UglyTest < MiniTest::Test
 
     def test_Ruby_style_interpolated_attribute
       haml    = %q{%p{:a =>"#{var}"}}
-      html    = %q{<p a='value'></p>}
+      _html   = %q{<p a='value'></p>}
       locals  = {:var=>"value"}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -634,7 +634,7 @@ class UglyTest < MiniTest::Test
 
     def test_Ruby_style_multiple_attributes
       haml    = %q{%p{ :a => 'b', 'c' => 'd' }}
-      html    = %q{<p a='b' c='d'></p>}
+      _html   = %q{<p a='b' c='d'></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -645,7 +645,7 @@ class UglyTest < MiniTest::Test
     def test_Ruby_style_attributes_separated_with_newlines
       haml    = %q{%p{ :a => 'b',
   'c' => 'd' }}
-      html    = %q{<p a='b' c='d'></p>}
+      _html   = %q{<p a='b' c='d'></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -655,7 +655,7 @@ class UglyTest < MiniTest::Test
 
     def test_Ruby_style_class_as_an_attribute
       haml    = %q{%p{:class => 'class1'}}
-      html    = %q{<p class='class1'></p>}
+      _html   = %q{<p class='class1'></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -665,7 +665,7 @@ class UglyTest < MiniTest::Test
 
     def test_Ruby_style_tag_with_a_CSS_class_and_class_as_an_attribute
       haml    = %q{%p.class2{:class => 'class1'}}
-      html    = %q{<p class='class1 class2'></p>}
+      _html   = %q{<p class='class1 class2'></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -675,7 +675,7 @@ class UglyTest < MiniTest::Test
 
     def test_Ruby_style_tag_with_id_as_an_attribute
       haml    = %q{%p{:id => '1'}}
-      html    = %q{<p id='1'></p>}
+      _html   = %q{<p id='1'></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -685,7 +685,7 @@ class UglyTest < MiniTest::Test
 
     def test_Ruby_style_tag_with_a_CSS_id_and_id_as_an_attribute
       haml    = %q{%p#id{:id => '1'}}
-      html    = %q{<p id='id_1'></p>}
+      _html   = %q{<p id='id_1'></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -695,7 +695,7 @@ class UglyTest < MiniTest::Test
 
     def test_Ruby_style_tag_with_a_CSS_id_and_a_numeric_id_as_an_attribute
       haml    = %q{%p#id{:id => 1}}
-      html    = %q{<p id='id_1'></p>}
+      _html   = %q{<p id='id_1'></p>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -705,7 +705,7 @@ class UglyTest < MiniTest::Test
 
     def test_Ruby_style_tag_with_a_variable_attribute
       haml    = %q{%p{:class => var}}
-      html    = %q{<p class='hello'></p>}
+      _html   = %q{<p class='hello'></p>}
       locals  = {:var=>"hello"}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -715,7 +715,7 @@ class UglyTest < MiniTest::Test
 
     def test_Ruby_style_tag_with_a_CSS_class_and_class_as_a_variable_attribute
       haml    = %q{.hello{:class => var}}
-      html    = %q{<div class='hello world'></div>}
+      _html   = %q{<div class='hello world'></div>}
       locals  = {:var=>"world"}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -725,7 +725,7 @@ class UglyTest < MiniTest::Test
 
     def test_Ruby_style_tag_multiple_CSS_classes_sorted_correctly_
       haml    = %q{.z{:class => var}}
-      html    = %q{<div class='a z'></div>}
+      _html   = %q{<div class='a z'></div>}
       locals  = {:var=>"a"}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -737,7 +737,7 @@ class UglyTest < MiniTest::Test
   class Silentcomments < MiniTest::Test
     def test_an_inline_silent_comment
       haml    = %q{-# hello}
-      html    = %q{}
+      _html   = %q{}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -748,7 +748,7 @@ class UglyTest < MiniTest::Test
     def test_a_nested_silent_comment
       haml    = %q{-#
   hello}
-      html    = %q{}
+      _html   = %q{}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -760,7 +760,7 @@ class UglyTest < MiniTest::Test
       haml    = %q{-#
   %div
     foo}
-      html    = %q{}
+      _html   = %q{}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -772,7 +772,7 @@ class UglyTest < MiniTest::Test
       haml    = %q{-#
   %div
       foo}
-      html    = %q{}
+      _html   = %q{}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -784,7 +784,7 @@ class UglyTest < MiniTest::Test
   class Markupcomments < MiniTest::Test
     def test_an_inline_markup_comment
       haml    = %q{/ comment}
-      html    = %q{<!-- comment -->}
+      _html   = %q{<!-- comment -->}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -796,7 +796,7 @@ class UglyTest < MiniTest::Test
       haml    = %q{/
   comment
   comment2}
-      html    = %q{<!--
+      _html   = %q{<!--
   comment
   comment2
 -->}
@@ -812,7 +812,7 @@ class UglyTest < MiniTest::Test
     def test_a_conditional_comment
       haml    = %q{/[if IE]
   %p a}
-      html    = %q{<!--[if IE]>
+      _html   = %q{<!--[if IE]>
   <p>a</p>
 <![endif]-->}
       locals  = {}
@@ -827,7 +827,7 @@ class UglyTest < MiniTest::Test
     def test_content_in_an_escaped_filter
       haml    = %q{:escaped
   <&">}
-      html    = %q{&lt;&amp;&quot;&gt;}
+      _html   = %q{&lt;&amp;&quot;&gt;}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -840,7 +840,7 @@ class UglyTest < MiniTest::Test
   hello
 
 %p}
-      html    = %q{hello&#x000A;
+      _html   = %q{hello&#x000A;
 <p></p>}
       locals  = {}
       options = {}
@@ -854,7 +854,7 @@ class UglyTest < MiniTest::Test
   hello
 
 %p}
-      html    = %q{hello
+      _html   = %q{hello
 <p></p>}
       locals  = {}
       options = {}
@@ -868,7 +868,7 @@ class UglyTest < MiniTest::Test
   hello
 
 %p}
-      html    = %q{<style type='text/css'>
+      _html   = %q{<style type='text/css'>
   /*<![CDATA[*/
     hello
   /*]]>*/
@@ -885,7 +885,7 @@ class UglyTest < MiniTest::Test
       haml    = %q{:javascript
   a();
 %p}
-      html    = %q{<script type='text/javascript'>
+      _html   = %q{<script type='text/javascript'>
   //<![CDATA[
     a();
   //]]>
@@ -903,7 +903,7 @@ class UglyTest < MiniTest::Test
   hello
 
 %p}
-      html    = %q{<style>
+      _html   = %q{<style>
   hello
 </style>
 <p></p>}
@@ -918,7 +918,7 @@ class UglyTest < MiniTest::Test
       haml    = %q{:javascript
   a();
 %p}
-      html    = %q{<script>
+      _html   = %q{<script>
   a();
 </script>
 <p></p>}
@@ -933,7 +933,7 @@ class UglyTest < MiniTest::Test
   class Rubystyleinterpolation < MiniTest::Test
     def test_interpolation_inside_inline_content
       haml    = %q{%p #{var}}
-      html    = %q{<p>value</p>}
+      _html   = %q{<p>value</p>}
       locals  = {:var=>"value"}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -943,7 +943,7 @@ class UglyTest < MiniTest::Test
 
     def test_no_interpolation_when_escaped
       haml    = %q{%p \#{var}}
-      html    = %q{<p>#{var}</p>}
+      _html   = %q{<p>#{var}</p>}
       locals  = {:var=>"value"}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -953,7 +953,7 @@ class UglyTest < MiniTest::Test
 
     def test_interpolation_when_the_escape_character_is_escaped
       haml    = %q{%p \\#{var}}
-      html    = %q{<p>\value</p>}
+      _html   = %q{<p>\value</p>}
       locals  = {:var=>"value"}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -964,7 +964,7 @@ class UglyTest < MiniTest::Test
     def test_interpolation_inside_filtered_content
       haml    = %q{:plain
   #{var} interpolated: #{var}}
-      html    = %q{value interpolated: value}
+      _html   = %q{value interpolated: value}
       locals  = {:var=>"value"}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -976,7 +976,7 @@ class UglyTest < MiniTest::Test
   class Htmlescaping < MiniTest::Test
     def test_code_following_
       haml    = %q{&= '<"&>'}
-      html    = %q{&lt;&quot;&amp;&gt;}
+      _html   = %q{&lt;&quot;&amp;&gt;}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -984,9 +984,9 @@ class UglyTest < MiniTest::Test
       assert_equal haml_result, hamlit_result
     end
 
-    def test_code_following_when_escape_haml_is_set_to_true
+    def test_code_following_eq_when_escape_haml_is_set_to_true
       haml    = %q{= '<"&>'}
-      html    = %q{&lt;&quot;&amp;&gt;}
+      _html   = %q{&lt;&quot;&amp;&gt;}
       locals  = {}
       options = {:escape_html=>"true"}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -994,9 +994,9 @@ class UglyTest < MiniTest::Test
       assert_equal haml_result, hamlit_result
     end
 
-    def test_code_following_when_escape_haml_is_set_to_true
+    def test_code_following_neq_when_escape_haml_is_set_to_true
       haml    = %q{!= '<"&>'}
-      html    = %q{<"&>}
+      _html   = %q{<"&>}
       locals  = {}
       options = {:escape_html=>"true"}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -1008,7 +1008,7 @@ class UglyTest < MiniTest::Test
   class Booleanattributes < MiniTest::Test
     def test_boolean_attribute_with_XHTML
       haml    = %q{%input(checked=true)}
-      html    = %q{<input checked='checked' />}
+      _html   = %q{<input checked='checked' />}
       locals  = {}
       options = {:format=>:xhtml}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -1018,7 +1018,7 @@ class UglyTest < MiniTest::Test
 
     def test_boolean_attribute_with_HTML
       haml    = %q{%input(checked=true)}
-      html    = %q{<input checked>}
+      _html   = %q{<input checked>}
       locals  = {}
       options = {:format=>:html5}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -1030,7 +1030,7 @@ class UglyTest < MiniTest::Test
   class Whitespacepreservation < MiniTest::Test
     def test_following_the_operator
       haml    = %q{~ "Foo\n<pre>Bar\nBaz</pre>"}
-      html    = %q{Foo
+      _html   = %q{Foo
 <pre>Bar&#x000A;Baz</pre>}
       locals  = {}
       options = {}
@@ -1043,7 +1043,7 @@ class UglyTest < MiniTest::Test
       haml    = %q{%textarea
   hello
   hello}
-      html    = %q{<textarea>hello
+      _html   = %q{<textarea>hello
 hello</textarea>}
       locals  = {}
       options = {}
@@ -1056,7 +1056,7 @@ hello</textarea>}
       haml    = %q{%pre
   hello
   hello}
-      html    = %q{<pre>hello
+      _html   = %q{<pre>hello
 hello</pre>}
       locals  = {}
       options = {}
@@ -1071,7 +1071,7 @@ hello</pre>}
       haml    = %q{%li hello
 %li> world
 %li again}
-      html    = %q{<li>hello</li><li>world</li><li>again</li>}
+      _html   = %q{<li>hello</li><li>world</li><li>again</li>}
       locals  = {}
       options = {}
       haml_result = UglyTest.haml_result(haml, options, locals)
@@ -1084,7 +1084,7 @@ hello</pre>}
 %li>
   world
 %li again}
-      html    = %q{<li>hello</li><li>
+      _html   = %q{<li>hello</li><li>
   world
 </li><li>again</li>}
       locals  = {}
@@ -1098,7 +1098,7 @@ hello</pre>}
       haml    = %q{%p<
   hello
   world}
-      html    = %q{<p>hello
+      _html   = %q{<p>hello
 world</p>}
       locals  = {}
       options = {}
@@ -1107,4 +1107,4 @@ world</p>}
       assert_equal haml_result, hamlit_result
     end
   end
-end
+end if RUBY_ENGINE != 'truffleruby' # truffleruby cannot run Haml
